/* +++++++++++++++++++++++++++++++++++++++++++++++++++

       Ejemplo para simulación de AMR7TDMI de NXP
       LPC2114 con GDB de GNUARM (www.gnuarm.org)
       
       
++++++++++++++++++++++++++++++++++++++++++++++++++++*/

#include "lpc2114.h"

/* +++++++++++++++++++++++++++++++++++++++++++++++++++
 DEFINICIONES DEL PUERTO CERO:
   
 GPIO0_IOPIN dirección 0xE0028000 ESTADO DEL PUERTO 0
 GPIO0_IOSET dirección 0xE0028004 SETEO DEL PUERTO 0
 GPIO0_IODIR dirección 0xE0028008 ENTRADA/SALIDA DEL PUERTO 0
 GPIO0_IOCLR dirección 0xE002800C BORRADO DEL PUERTO CERO

+++++++++++++++++++++++++++++++++++++++++++++++++++++*/

int main (void)
	{
	 	GPIO0_IODIR = 0xFFFFFFFF; 
   	
   	int a=0;

		GPIO0_IOSET = 0x00000000; // seteo en 0 el puerto 0 
	
		
		while (1)
		{  
			if(GPIO0_IOPIN & (1<<22) )	//Si está seteado pin P0.22 			
		 		{  a=100;
		 		};
		 	if(GPIO0_IOPIN & (1<<21) )   //Si está seteado pin P0.21 			
		  		{  a=50;
		 		};
		 };
	return 0;
   }


